--[[
	Fraglimit v1.0
	by Kiffer-Opa
	
	This script adds a frag limit to your server.
	recommended for DM, TDM and Construction game modes
	- in DM, the goal of every player is to reach the frag limit first to win
	- in TDM and Construction, the scores of all players in a team are added together
		for a team score. The first team who reaches the frag limit, wins
	
	usage: either edit the line "dmmode.fraglimit = 50" to set the initial frag limit to
		another number
		
		or on run time, after you loaded this script type in console:
			lua dmmode.setfraglimit(frags)
		where "frags" is the number of frags needed to win. 
		set "frags" to nil to disable the frag limit
]]

if dmmode == nil then dmmode = {} end

-- the frag limit:
dmmode.fraglimit = 50


dmmode.imgs = nil
dmmode.idle = false

--dofile("sys/lua/wpnids.lua")	-- v1.3
if wrapper~=true then dofile("sys/lua/wrapper.lua") end 

function dmmode.setfraglimit(frags)
	dmmode.fraglimit = frags
	dmmode.hud()
end

function dmmode.ypos(playerID)
	local ybase
	if(player(playerID,"health")>0) then
		ybase = 460
	else
		ybase = 420
	end
	return ybase
end

function dmmode.spawn(playerID)
	dmmode.hud()
end
addhook("spawn","dmmode.spawn")

function dmmode.leave(playerID, reason)
	if(dmmode.imgs[playerID] ~= nil) then
		dmmode.imgs[playerID] = nil
	end
end
addhook("leave","dmmode.leave")

function dmmode.hud()
	local players=player(0,"table")
	
	if(tonumber(game("sv_gamemode"))~=1 and tonumber(game("sv_gamemode"))~=4) then
		local teamshort = {"T","CT"}
		local teamscore = {0,0}
		
		for i=1,#players do
			p=players[i]
			local team = player(p,"team")
			if(team~=0) then
				teamscore[team] = teamscore[team] + player(p,"score")
			end
		end
		
		if(dmmode.fraglimit~=nil) then
			for team=1,2 do
				if(teamscore[team]>=dmmode.fraglimit and dmmode.idle == false) then
					dmmode.idle = true
					dmmode.winbyfrags(team)
				end
			end
		
			if(dmmode.imgs == nil) then
				dmmode.imgs = {}
			end
		
			for i=1,#players do
				local p = players[i]
				if(player(p,"bot")==false) then
					ybase = dmmode.ypos(p)
					
					
					if(dmmode.imgs[p] == nil) then
						dmmode.imgs[p] = {}
						dmmode.imgs[p].t = image("gfx/sprites/block.bmp", 280,ybase, 2, p)
						dmmode.imgs[p].limit = image("gfx/sprites/block.bmp", 330,ybase, 2, p)
						dmmode.imgs[p].ct = image("gfx/sprites/block.bmp", 380,ybase, 2, p)
						
						imagealpha(dmmode.imgs[p].t,0.5)
						imagealpha(dmmode.imgs[p].ct,0.5)
						imagealpha(dmmode.imgs[p].limit,0.5)
						
						imagecolor(dmmode.imgs[p].t, 255,25,0)
						imagecolor(dmmode.imgs[p].ct, 50,150,255)
						imagecolor(dmmode.imgs[p].limit, 255,255,0)	
					end
					
					
					imagepos(dmmode.imgs[p].t, 280, ybase, 0)
					imagepos(dmmode.imgs[p].limit, 330, ybase, 0)
					imagepos(dmmode.imgs[p].ct, 380, ybase, 0)
					
					parse('hudtxt2 '..p..' 0 "255025000'..teamshort[1]..'" 280 '..(ybase-15)..' 1')
					parse('hudtxt2 '..p..' 1 "255255000limit" 330 '..(ybase-15)..' 1')
					parse('hudtxt2 '..p..' 2 "050150255'..teamshort[2]..'" 380 '..(ybase-15)..' 1')
					
					parse('hudtxt2 '..p..' 3 "255025000'..teamscore[1]..'" 280 '..ybase..' 1')
					parse('hudtxt2 '..p..' 4 "255255000'..dmmode.fraglimit..'" 330 '..ybase..' 1')
					parse('hudtxt2 '..p..' 5 "050150255'..teamscore[2]..'" 380 '..ybase..' 1')
				end
			end
		end
	else
		-- HUD for Deathmatch
		if(dmmode.fraglimit~=nil) then
			local leader = nil
			for i=1,#players do
				p=players[i]
				if(leader==nil) then
					leader=player(p,"score")
				elseif(player(p,"score")>leader) then
					leader=player(p,"score") 
				end
			end
			
			if(dmmode.imgs == nil) then
				dmmode.imgs = {}
			end	
			
			for i=1,#players do
				p=players[i]
				if(player(p,"bot")==false) then
					ybase = dmmode.ypos(p)
					
					
					if(dmmode.imgs[p] == nil) then
						dmmode.imgs[p] = {}
						dmmode.imgs[p].limit = image("gfx/sprites/block.bmp", 280,ybase, 2, p)
						dmmode.imgs[p].leader = image("gfx/sprites/block.bmp", 330,ybase, 2, p)
						dmmode.imgs[p].you = image("gfx/sprites/block.bmp", 380,ybase, 2, p)
					
						imagealpha(dmmode.imgs[p].limit,0.5)
						imagealpha(dmmode.imgs[p].leader,0.5)
						imagealpha(dmmode.imgs[p].you,0.75)
						
						imagecolor(dmmode.imgs[p].limit, 255,255,0)
						imagecolor(dmmode.imgs[p].leader, 0,255,0)
						imagecolor(dmmode.imgs[p].you, 0,255,0)			
					end
					
					imagepos(dmmode.imgs[p].limit, 280, ybase, 0)
					imagepos(dmmode.imgs[p].leader, 330, ybase, 0)
					imagepos(dmmode.imgs[p].you, 380, ybase, 0)
					
					parse('hudtxt2 '..p..' 0 "255255000limit" 280 '..(ybase-15)..' 1')
					parse('hudtxt2 '..p..' 1 "000255000lead" 330 '..(ybase-15)..' 1')
					parse('hudtxt2 '..p..' 2 "000255000you" 380 '..(ybase-15)..' 1')
					
					parse('hudtxt2 '..p..' 3 "255255000'..dmmode.fraglimit..'" 280 '..ybase..' 1')
					parse('hudtxt2 '..p..' 4 "000255000'..leader..'" 330 '..ybase..' 1')
					parse('hudtxt2 '..p..' 5 "000255000'..player(p,"score")..'" 380 '..ybase..' 1')
				end
			end
		end
	end
end

function dmmode.kill(killer,victim,weapon,x,y)
	if(type(dmmode.fraglimit)=="number") then
		if(tonumber(game("sv_gamemode"))==1) then
			local players = player(0,"table")
			for p=1,#players do
				local pl=players[p]
				if(player(pl,"score")>=dmmode.fraglimit and dmmode.idle==false) then
					dmmode.idle = true
					dmmode.winbyfrags(pl)
				end
			end	
		end
	end
	
	dmmode.hud()
end
addhook("kill","dmmode.kill")

function dmmode.winbyfrags(winner)
	if(tonumber(game("sv_gamemode"))==1) then
		msg("000255000"..player(winner,"name").." wins with "..player(winner,"score").." frags!@C")
	else
		if(winner==1) then
			msg("Terrorists win!@C")
			parse("sv_sound radio/terwin.ogg")
		elseif(winner==2) then
			msg("Counter-Terrorists win!@C")
			parse("sv_sound radio/ctwin.ogg")
		end
	end
	timer(5000,"dmmode.restart")
end

function dmmode.restart()
	parse("restart")
end

function dmmode.initround(mode)
	dmmode.imgs = nil
	dmmode.idle = false
	dmmode.hud()
end
addhook("startround","dmmode.initround")

function dmmode.legalitem(itemid)
	--[[ defines which items are allowed in arena mode 
	and which not ]]
	local t=itemid
	if(t~=Bomb and t~=PlantedBomb and (t<79 or t>84) and t~=Medikit and t~=Bandage and t~=RedFlag and t~=BlueFlag and (t<56 or t>59)) then
		-- don't remove ammo items when playing with finite ammo
		if((dmmode.arena.infammo==false and t~=PrimaryAmmo and t~=SecondaryAmmo) or dmmode.arena.infammo==true) then
			return false
		else
			return true
		end
	else
		return true
	end
end






if(dmmode.fraglimit~=nil) then
	dmmode.setfraglimit(dmmode.fraglimit)
end